itkwasm.pyodide - itkwasm python documentation
Description: Module Contents: Classes:,, JsPackageConfig,,, JsPackage,,, JsResources,,,,, Functions:,, to_py,,, to_js,,,,, Data:,, js_resources,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `itkwasm.pyodide`

## Module Contents

### Classes

`JsPackageConfig` |
`JsPackage` |
`JsResources` |

### Functions

`to_py` |
`to_js` |

### Data

`js_resources` |

### API

class itkwasm.pyodide.JsPackageConfig
  module_url: str

    None

  pipelines_base_url: Optional[str]

    None

  pipeline_worker_url: Optional[str]

    None

class itkwasm.pyodide.JsPackage(config: itkwasm.pyodide.JsPackageConfig)

  Initialization

  property config
  property js_module

class itkwasm.pyodide.JsResources

  Initialization

  property web_worker

itkwasm.pyodide.js_resources

  None

itkwasm.pyodide.to_py(js_proxy)

itkwasm.pyodide.to_js(py)